import React, { Component } from 'react';
import { fetchPublicCarList } from '../../api/index';
import { PullToRefresh } from 'antd-mobile';
import styles from './style.css';
import PublicCarItem from './components/PublicCarItem';

class PublicCarList extends Component {
  constructor(props) {
    super(props);
    this.state = {
      refreshing: false,
      down: true,
      height: document.documentElement.clientHeight,
      list: [],
      pagination: {
        lastIndex: null,
        pageNum: 1,
        pageSize: 50,
      },
    };
  }

  componentDidMount() {
    let wrap = document.querySelector('.RepairContent');
    const hei = wrap.clientHeight;
    setTimeout(
      () =>
        this.setState({
          height: hei,
        }),
      0
    );
    this.fetchList();
  }
  fetchList = () => {
    const { pagination } = this.state;
    return fetchPublicCarList({ ...pagination })
      .then(res => {
        console.log(res);
        if (res.data) {
          this.setState(({ pagination }) => ({
            list: res.data,
            pagination: {
              ...pagination,
              lastIndex: res.data[res.data.length - 1].lastIndex,
            },
          }));
        }
      })
      .catch(err => {
        console.log(err);
      });
  };
  refreshHandle = () => {
    this.setState({ refreshing: true });
    this.fetchList().then(() => {
      this.setState({ refreshing: false });
    });
  };
  render() {
    return (
      <div className={styles.publicCarList}>
        <PullToRefresh
          damping={60}
          ref={el => (this.ptr = el)}
          style={{
            height: this.state.height,
            overflow: 'auto',
          }}
          indicator={{ deactivate: '上拉可以刷新' }}
          direction={'up'}
          refreshing={this.state.refreshing}
          onRefresh={this.refreshHandle}
        >
          <div className={styles.listInfo}>显示最近半年的报修记录</div>
          {this.state.list.length ? (
            this.state.list.map(i => <PublicCarItem key={i.id} data={i} />)
          ) : (
            <div className={styles.noData}>暂无数据</div>
          )}
        </PullToRefresh>
      </div>
    );
  }
}

export default PublicCarList;
